@@ -1,5 +1,3 @@
-{-# LANGUAGE OverloadedStrings #-}
-{-# LANGUAGE CPP #-}
 import Test.Hspec.Monadic
 import Test.Hspec.HUnit ()
 import Test.Hspec.QuickCheck (prop)
@@ -23,3 +21,11 @@ main = hspecX $ do
                 src = mconcat $ map (CL.sourceList . return) bss
             outBss <- src C.$= CZ.gzip C.$= CZ.ungzip C.$$ CL.consume
             return $ lbs == L.fromChunks outBss
+        prop "flush" $ \bss' -> runST $ runResourceT $ do
+            let bss = map S.pack $ filter (not . null) bss'
+                bssC = concatMap (\bs -> [C.Chunk bs, C.Flush]) bss
+                src = mconcat $ map (CL.sourceList . return) bssC
+            outBssC <- src C.$= CZ.compressFlush 5 (CZ.WindowBits 31)
+                           C.$= CZ.decompressFlush (CZ.WindowBits 31)
+                           C.$$ CL.consume
+            return $ bssC == outBssC
